using System;
using System.Text;
using System.Reflection;
using System.Diagnostics;

namespace MyDbg
{

/// <sumarry> This class provides tracing and assert checking functionality.</sumarry>
public class Dbg
{

	public Dbg() { }

	/// <summary>
	/// Displays all fields in a object.
	/// </summary>
	/// <param name="obj">Instance object</param>
	/// <remarks>
	/// Pass object whose state you want to see.
	/// </remarks>
	public static string DisplayObject(
		object obj
		)
	{
		StringBuilder  sbInfo = null;
		Type obType = obj.GetType();

		try
		{
			sbInfo = new StringBuilder();
		}
		catch (OutOfMemoryException e)
		{
			Console.WriteLine(e.Message);
			return null;
		}
       	try
      	{
        	// Get the FieldInfo of the class MyClass.
         	FieldInfo[] myFields = obType.GetFields(BindingFlags.Public | 
							BindingFlags.Static | BindingFlags.NonPublic | 
							BindingFlags.Instance);
			
         	for(int i = 0; i < myFields.Length; i++)
         	{
				sbInfo.AppendFormat("{0} : {1}\n", myFields[i].Name, myFields[i].GetValue(obj));
         	}
      	}  
      	catch(FieldAccessException e)
      	{
         	Console.WriteLine("FieldAccessException : {0}", e.Message);
      	}
      	catch(TargetException e)
      	{
         	Console.WriteLine("TargetException : {0}", e.Message);
      	}
      	catch(ExecutionEngineException e)
      	{
         	Console.WriteLine("ExecutionEngineException : {0}", e.Message);
      	}
      	catch(MemberAccessException e)
      	{
         	Console.WriteLine("MemberAccessException : {0}", e.Message);
      	}
      	catch(Exception e)
      	{
         	Console.WriteLine("Exception : {0}", e.Message);
      	}

		return sbInfo.ToString();
	} // DisplayObject

	/// <summary>
	/// Returns all static fields of a class.
	/// </summary>
	/// <param name="sType">class name</param>
	/// <remarks>
	/// Pass fully qualified class name as the parameter.
	/// </remarks>
	public static string DisplayClass(
		string name
		)
	{
		StringBuilder  sbInfo = null;
		Type		   sType = null;

		sType = Type.GetType(name);

		try
		{
			sbInfo = new StringBuilder();
		}
		catch (OutOfMemoryException e)
		{
			Console.WriteLine(e.Message);
			return null;
		}

       	try
      	{
        	// Get the FieldInfo of the class MyClass.
         	FieldInfo[] myFields = sType.GetFields(BindingFlags.Public | 
							BindingFlags.Static | BindingFlags.NonPublic);
         	// Display the values of the fields to the console.
         	for(int i = 0; i < myFields.Length; i++)
         	{
				sbInfo.AppendFormat("{0} : {1}\n", 
								    myFields[i].Name, 
									myFields[i].GetValue(null));
         	}
      	}  
      	catch(FieldAccessException e)
      	{
         	Console.WriteLine("FieldAccessException : {0}", e.Message);
      	}
      	catch(TargetException e)
      	{
         	Console.WriteLine("TargetException : {0}", e.Message);
      	}
      	catch(ExecutionEngineException e)
      	{
         	Console.WriteLine("ExecutionEngineException : {0}", e.Message);
      	}
      	catch(MemberAccessException e)
      	{
         	Console.WriteLine("MemberAccessException : {0}", e.Message);
      	}
      	catch(Exception e)
      	{
         	Console.WriteLine("Exception : {0}", e.Message);
      	}

		return sbInfo.ToString();
	} // DisplayClass

	/// <sumarry> Overloaded ToString(). </sumarry>
	public override string ToString()
	{
		return DisplayObject(this);
	}
} // class Dbg
}
